menu
vatcheckapi package
documentation
vatcheckapi.dart
VatcheckapiClient class
VatcheckapiClient class
dark_mode
light_mode
VatcheckapiClient
class
Constructors
VatcheckapiClient
(
String
apiKey
, {
Uri
?
baseUri
})
Properties
apiKey
→
String
final
baseUri
→
Uri
final
hashCode
→
int
The hash code for this object.
no setter
inherited
runtimeType
→
Type
A representation of the runtime type of the object.
no setter
inherited
Methods
noSuchMethod
(
Invocation
invocation
)
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
status
(
)
→
Future
<
Map
<
String
,
dynamic
>
>
toString
(
)
→
String
A string representation of this object.
inherited
validate
(
String
vat
)
→
Future
<
Map
<
String
,
dynamic
>
>
Operators
operator ==
(
Object
other
)
→
bool
The equality operator.
inherited
vatcheckapi package
documentation
vatcheckapi
VatcheckapiClient class
vatcheckapi library